service daemon/squid {
	need = system/initial system/hostname system/rundir;
	require_network;
	nice = +5;

	script start = {
		# Sanity check
		[ -f /etc/squid/squid.conf ] || exit 0

		# Source function library
		. /etc/rc.d/init.d/functions

		# Get service config
		[ -f /etc/sysconfig/squid ] && . /etc/sysconfig/squid

		msg_starting Squid
		ulimit -n 8192
		daemon squid $SQUID_OPTS
		RETVAL=$?
		[ $RETVAL -eq 0 ] && touch /var/lock/subsys/squid

		exit $RETVAL
	}

	script stop = {
		# Sanity check
		[ -f /etc/squid/squid.conf ] || exit 0

		# Source function library
		. /etc/rc.d/init.d/functions

		# Get service config
		[ -f /etc/sysconfig/squid ] && . /etc/sysconfig/squid

		# Set default shutdown timeout if it is not set in service config
		SQUID_SHUTDOWN_TIMEOUT=${SQUID_SHUTDOWN_TIMEOUT:-60}

		msg_stopping Squid

		if [ -f /var/run/squid.pid ]; then
			PID=$(filter_chroot `cat /var/run/squid.pid`)
			if [ -z "$PID" ]; then
				PID=0
			fi
		else
			PID=0
		fi
		killproc squid
		RETVAL=$?
		if [ ! $PID -eq 0 ]; then
			show "Waiting for Squid to stop"
			busy
			timeout=0
			while ps -U squid -o user | grep -q ^squid
			do
				if [ $timeout -ge $SQUID_SHUTDOWN_TIMEOUT ]; then
					break
				fi
				sleep 1
				timeout=$((timeout+1))
			done
			ok
		fi
		rm -f /var/lock/subsys/squid >/dev/null 2>&1

		exit $RETVAL
	}
}
